const path = require('path');
const fs = require('fs');

const moduleFileExtensions = [
  'web.mjs',
  'mjs',
  'web.js',
  'js',
  'web.ts',
  'ts',
  'web.tsx',
  'tsx',
  'json',
  'web.jsx',
  'jsx',
];

const resolveModule = (resolveFn, filePath) => {
  const extention = moduleFileExtensions.find(ext => {
    if(fs.existsSync(resolveFn(`${filePath}.${ext}`))) {
      return ext;
    }
  });
  if(extention) {
    return resolveFn(`${filePath}.${extention}`);
  }
  return resolveFn(`${filePath}.js`)
}

const resolvePath = (relativePath) => {
  return path.resolve(fs.realpathSync(process.cwd()), relativePath);
}

module.exports = {
  entry: resolveModule(resolvePath, 'src/index'),
  build: resolvePath('build'),
  publicHTML: resolvePath('public/index.html'),
  content: resolvePath('public'),
  app: resolvePath('.'),
  package: resolvePath('package.json'),
  public: resolvePath('public'),
  proxy: resolveModule(resolvePath, 'config/proxy.config'),
  appSrc: resolvePath('src'),
  mock: resolvePath('mock'),
};