const browserslist = require("browserslist");
const pkgUp = require("pkg-up");
const inquirer = require("inquirer");
const fs = require("fs");
const os = require("os");
const chalk = require('chalk');

const defaultBrowsers = {
  production: ['>0.2%', 'not dead', 'not op_mini all'],
  development: [
    'last 1 chrome version',
    'last 1 firefox version',
    'last 1 safari version',
  ],
};

// browser helpers
function checkBrowsers(dir, retry = true) {
  var current = browserslist.loadConfig({path: dir});
  if (current) {
    return Promise.resolve(current);
  }

  if (!retry) {
    return Promise.reject(
      new Error(
        chalk.red(
          'As of react-scripts >=2 you must specify targeted browsers.'
        ) +
          os.EOL +
          `Please add a ${chalk.underline(
            'browserslist'
          )} key to your ${chalk.bold('package.json')}.`
      )
    );
  }

  return shouldSetBrowsers().then(shouldSetBrowsers => {
    if (!shouldSetBrowsers) {
      checkBrowsers(dir, false);
    }

    return pkgUp(dir)
      .then(filePath => {
        // console.log('pkgup', filePath);
        if (!filePath) {
          return Promise.reject();
        }

        const pkg = JSON.parse(fs.readFileSync(filePath));
        pkg["browserslist"] = defaultBrowsers;

        fs.writeFileSync(filePath, JSON.stringify(pkg, null, 2) + os.EOL);
        browserslist.clearCaches();

        console.log(
          `\n${chalk.green('Set target browsers:')} ${chalk.cyan(
            defaultBrowsers.join(', ')
          )}\n`
        );
      })
      .catch(() => {})
      .then(() => {
        checkBrowsers(dir, false);
      });
  });
}

function shouldSetBrowsers() {
  const question = {
    default: true,
    name: "shouldSetBrowsers",
    message: chalk.yellow("We're unable to detect target browsers.") +
    `\n\nWould you like to add the defaults to your ${chalk.bold(
      'package.json'
    )}?`,
    type: "confirm"
  };

  return inquirer.prompt(question).then(answer => {
    // console.log('answer', answer);
    return answer.shouldSetBrowsers;
  });
}

module.exports = { checkBrowsers };
