const chalk = require("chalk");
const address = require('address');
const url = require('url');

function prepareUrls(protocol, host, port) {
  const formatUrl = hostname =>
    url.format({
      protocol,
      hostname,
      port,
      pathname: "/"
    });
  const prettyPrintUrl = hostname =>
    url.format({
      protocol,
      hostname,
      port: chalk.bold(port),
      pathname: "/"
    });

  // handle
  var isUnspecifiedHost = host === '0.0.0.0' || host === '::';
  var prettyHost, lanUrlForConfig, lanUrlForTerminal;
  if(isUnspecifiedHost) {
    prettyHost = 'localhost';
    lanUrlForConfig = address.ip();
    if(/^10[.]|^172[.](1[6-9]|2[0-9]|3[0-1])[.]|^192[.]168[.]/.test(lanUrlForConfig)) {
      lanUrlForTerminal = prettyPrintUrl(lanUrlForConfig);
    } else {
      lanUrlForConfig = undefined;
    }
  } else {
    prettyHost = host;
  }

  const localUrlForTerminal = prettyPrintUrl(prettyHost);
  const localLanUrlForBrowser = formatUrl(prettyHost);
  // console.log(lanUrlForConfig, lanUrlForTerminal, localLanUrlForBrowser, localLanUrlForTerminal);
  return {
    lanUrlForConfig,
    lanUrlForTerminal,
    localLanUrlForBrowser,
    localUrlForTerminal,
  };
}

module.exports = prepareUrls;
